ButtonSet

Struct ButtonSet 

pub struct ButtonSet(/* private fields */);
Set of Button

Implementations

Source

impl Set

pub const D_PAD: Self

The set of 4 D-Pad buttons (up, down, left, right)

pub fn new() -> Self

pub fn insert(&mut self, button: Button)

pub fn contains(self, button: Button) -> bool

Returns true if the set contains the button

pub fn contains_any(self, buttons: impl Into<Self>) -> bool

Returns true if the set contains any of the buttons in the other set.

Returns false if the other set is empty.

pub fn d_pad<T: From<i8>>(self) -> [T; 2]

Returns the d-pad buttons contained in this set as a 2d vector

The axes correspond to the playdate screen coordinate system (x is right, and y is down):

  • Left is [-1, 0]
  • Right is [1, 0]
  • Down is [0, 1]
  • Up is [0, -1]

If more than one D-Pad button is contained in the set, this method returns the sum of the vectors.